pub struct RecordWithConf {
pub rec: RecordFlatten,
pub conf: SettlementSettings,
}Expand description
Settlement settings and csv data are flushed to a new struct. It is used for converting into descriptive and detail data blocks
Fields
rec: RecordFlattenconf: SettlementSettingsImplementations