pub struct TwoDigitYears {
pub day: String,
pub month: String,
pub year: String,
}Expand description
The .aba file uses non-standard date format of DDMMYY.
Caveat is that the leap year validation is capped at year 9999.
This is a workaround that uses random two digits to make up a 4-digit year.
Please refer to <https://www.ietf.org/rfc/rfc3339.txt> for more info
Fields
day: Stringmonth: Stringyear: StringImplementations
Sourceimpl TwoDigitYears
impl TwoDigitYears